==> estateplat-common-1.2.3-20180207.100054-26-sources.jar: cn/gtmap/estateplat/model/resources/core/ZrzyQlr.java <==
package cn.gtmap.estateplat.model.resources.core;

import javax.persistence.Id;
import javax.persistence.Table;

/**
 * @author <a href="mailto:sunchao@gtmap.cn">sunchao</a>
 * @version 1.0, 2017-4-18
 * @description 自然资源权利人表
 */
@Table(name = "zrzy_qlr")
public class ZrzyQlr implements InsertVo{

    /**
     * @author <a href="mailto:sunchao@gtmap.cn">sunchao</a>
     * @description 权利人ID
     */
    @Id
    private String qlrid;
    /**
     * @author <a href="mailto:sunchao@gtmap.cn">sunchao</a>
     * @description 项目ID
     */
    private String proid;
    /**
     * @author <a href="mailto:sunchao@gtmap.cn">sunchao</a>
     * @description 权利人名称
     */
    private String qlrmc;
    /**
     * @author <a href="mailto:sunchao@gtmap.cn">sunchao</a>
     * @description 权利人类型
     */
    private String qlrlx;
    /**
     * @author <a href="mailto:sunchao@gtmap.cn">sunchao</a>
     * @description 权利人性质
     */
    private String qlrxz;
    /**
     * @author <a href="mailto:sunchao@gtmap.cn">sunchao</a>
     * @description 权利人证件类型
     */
    private String qlrzjlx;
    /**
     * @author <a href="mailto:sunchao@gtmap.cn">sunchao</a>
     * @description 权利人证件号
     */
    private String qlrzjh;
    /**
     * @author <a href="mailto:sunchao@gtmap.cn">sunchao</a>
     * @description 权利人电话
     */
    private String qlrdh;

    public String getQlrid() {
        return qlrid;
    }

    public void setQlrid(String qlrid) {
        this.qlrid = qlrid;
    }

    public String getProid() {
        return proid;
    }

    public void setProid(String proid) {
        this.proid = proid;
    }

    public String getQlrmc() {
        return qlrmc;
    }

    public void setQlrmc(String qlrmc) {
        this.qlrmc = qlrmc;
    }

    public String getQlrlx() {
        return qlrlx;
    }

    public void setQlrlx(String qlrlx) {
        this.qlrlx = qlrlx;
    }

    public String getQlrxz() {
        return qlrxz;
    }

    public void setQlrxz(String qlrxz) {
        this.qlrxz = qlrxz;
    }

    public String getQlrzjlx() {
        return qlrzjlx;
    }

    public void setQlrzjlx(String qlrzjlx) {
        this.qlrzjlx = qlrzjlx;
    }

    public String getQlrzjh() {
        return qlrzjh;
    }

    public void setQlrzjh(String qlrzjh) {
        this.qlrzjh = qlrzjh;
    }

    public String getQlrdh() {
        return qlrdh;
    }

    public void setQlrdh(String qlrdh) {
        this.qlrdh = qlrdh;
    }
}

==> estateplat-common-1.2.3-20180731.053311-158-sources.jar: cn/gtmap/estateplat/model/resources/core/ZrzyQlr.java <==
package cn.gtmap.estateplat.model.resources.core;

import javax.persistence.Id;
import javax.persistence.Table;

/**
 * @author <a href="mailto:sunchao@gtmap.cn">sunchao</a>
 * @version 1.0, 2017-4-18
 * @description 自然资源权利人表
 */
@Table(name = "zrzy_qlr")
public class ZrzyQlr implements InsertVo{

    /**
     * @author <a href="mailto:sunchao@gtmap.cn">sunchao</a>
     * @description 权利人ID
     */
    @Id
    private String qlrid;
    /**
     * @author <a href="mailto:sunchao@gtmap.cn">sunchao</a>
     * @description 项目ID
     */
    private String proid;
    /**
     * @author <a href="mailto:sunchao@gtmap.cn">sunchao</a>
     * @description 权利人名称
     */
    private String qlrmc;
    /**
     * @author <a href="mailto:sunchao@gtmap.cn">sunchao</a>
     * @description 权利人类型
     */
    private String qlrlx;
    /**
     * @author <a href="mailto:sunchao@gtmap.cn">sunchao</a>
     * @description 权利人性质
     */
    private String qlrxz;
    /**
     * @author <a href="mailto:sunchao@gtmap.cn">sunchao</a>
     * @description 权利人证件类型
     */
    private String qlrzjlx;
    /**
     * @author <a href="mailto:sunchao@gtmap.cn">sunchao</a>
     * @description 权利人证件号
     */
    private String qlrzjh;
    /**
     * @author <a href="mailto:sunchao@gtmap.cn">sunchao</a>
     * @description 权利人电话
     */
    private String qlrdh;

    private String xszt;//行使主体
    private String xsnr;//形式内容

    public String getQlrid() {
        return qlrid;
    }

    public void setQlrid(String qlrid) {
        this.qlrid = qlrid;
    }

    public String getProid() {
        return proid;
    }

    public void setProid(String proid) {
        this.proid = proid;
    }

    public String getQlrmc() {
        return qlrmc;
    }

    public void setQlrmc(String qlrmc) {
        this.qlrmc = qlrmc;
    }

    public String getQlrlx() {
        return qlrlx;
    }

    public void setQlrlx(String qlrlx) {
        this.qlrlx = qlrlx;
    }

    public String getQlrxz() {
        return qlrxz;
    }

    public void setQlrxz(String qlrxz) {
        this.qlrxz = qlrxz;
    }

    public String getQlrzjlx() {
        return qlrzjlx;
    }

    public void setQlrzjlx(String qlrzjlx) {
        this.qlrzjlx = qlrzjlx;
    }

    public String getQlrzjh() {
        return qlrzjh;
    }

    public void setQlrzjh(String qlrzjh) {
        this.qlrzjh = qlrzjh;
    }

    public String getQlrdh() {
        return qlrdh;
    }

    public void setQlrdh(String qlrdh) {
        this.qlrdh = qlrdh;
    }

    public String getXszt() {
        return xszt;
    }

    public void setXszt(String xszt) {
        this.xszt = xszt;
    }

    public String getXsnr() {
        return xsnr;
    }

    public void setXsnr(String xsnr) {
        this.xsnr = xsnr;
    }
}
